@@ -5,7 +5,7 @@ use warnings;
 use Carp qw/croak/;
 use XSLoader;
 
-our $VERSION = '3.012'; # Don't forget to update the TestCompat set for testing against installed encoders!
+our $VERSION = '3.014'; # Don't forget to update the TestCompat set for testing against installed encoders!
 our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
 
 # not for public consumption, just for testing.
@@ -136,7 +136,7 @@ my $flags= sub {
 
 sub flag_names {
     my ($self, $val)= @_;
-    return $flags->($val // $self->flags, _FLAG_NAME);
+    return $flags->(defined $val ? $val : $self->flags, _FLAG_NAME);
 }
 
 sub flag_names_volatile {
